==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaUmieszczajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DecyzjaUmieszczajaca extends GenericDPSObject {
    /**
     * DECYZJA_UMIESZCZAJACA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_UMIESZCZAJACA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWplywu;

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWydania;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_UMIESZCZAJACA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWplywu() {
        return dataWplywu;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     *
     * @param dataWplywu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWplywu(Date dataWplywu) {
        this.dataWplywu = dataWplywu;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaUmieszczajaca other = (DecyzjaUmieszczajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWplywu() == null ? other.getDataWplywu() == null : this.getDataWplywu().equals(other.getDataWplywu()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWplywu() == null) ? 0 : getDataWplywu().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWplywu=").append(dataWplywu);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaUmieszczajaca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DecyzjaUmieszczajaca extends GenericDPSObject {
    /**
     * DECYZJA_UMIESZCZAJACA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ktoWydalId;

    /**
     * DECYZJA_UMIESZCZAJACA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWplywu;

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWydania;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_UMIESZCZAJACA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKtoWydalId() {
        return ktoWydalId;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.KTO_WYDAL_ID
     *
     * @param ktoWydalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKtoWydalId(Long ktoWydalId) {
        this.ktoWydalId = ktoWydalId;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWplywu() {
        return dataWplywu;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WPLYWU
     *
     * @param dataWplywu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWplywu(Date dataWplywu) {
        this.dataWplywu = dataWplywu;
    }

    /**
     * @return DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWydania() {
        return dataWydania;
    }

    /**
     * DECYZJA_UMIESZCZAJACA.DATA_WYDANIA
     *
     * @param dataWydania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWydania(Date dataWydania) {
        this.dataWydania = dataWydania;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaUmieszczajaca other = (DecyzjaUmieszczajaca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getKtoWydalId() == null ? other.getKtoWydalId() == null : this.getKtoWydalId().equals(other.getKtoWydalId()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getDataWplywu() == null ? other.getDataWplywu() == null : this.getDataWplywu().equals(other.getDataWplywu()))
            && (this.getDataWydania() == null ? other.getDataWydania() == null : this.getDataWydania().equals(other.getDataWydania()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getKtoWydalId() == null) ? 0 : getKtoWydalId().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getDataWplywu() == null) ? 0 : getDataWplywu().hashCode());
        result = prime * result + ((getDataWydania() == null) ? 0 : getDataWydania().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", ktoWydalId=").append(ktoWydalId);
        sb.append(", nr=").append(nr);
        sb.append(", dataWplywu=").append(dataWplywu);
        sb.append(", dataWydania=").append(dataWydania);
        sb.append("]");
        return sb.toString();
    }
}
